# torchsar

PyTorch Tools for Synthetic Aperture Radar.

You can install and test ``torchsar`` by:

```bash
pip install torchsar
import torchsar as ts
print(ts.__version__)
```

Please see [torchsar's documentation](http://iridescent.ink/torchsar) for using details.
